@@ -15,7 +15,7 @@ REDISBOARD_DETAIL_FILTERS = [re.compile(name) for name in getattr(settings, 'RED
     'changes_since_last_save', 'db.*', 'db1', 'last_save_time',
     'multiplexing_api', 'total_commands_processed',
     'total_connections_received', 'uptime_in_days', 'uptime_in_seconds',
-    'vm_enabled'
+    'vm_enabled', 'redis_version'
 ))]
 REDISBOARD_DETAIL_TIMESTAMP_KEYS = getattr(settings, 'REDISBOARD_DETAIL_TIMESTAMP_KEYS', (
     'last_save_time',
